@@ -1,4 +1,4 @@
-from dagster._core.utils import check_dagster_package_version
+from dagster._core.libraries import DagsterLibraryRegistry
 
 from .asset_defs import (
     load_assets_from_dbt_manifest as load_assets_from_dbt_manifest,
@@ -50,4 +50,4 @@ from .rpc import (
 from .types import DbtOutput as DbtOutput
 from .version import __version__ as __version__
 
-check_dagster_package_version("dagster-dbt", __version__)
+DagsterLibraryRegistry.register("dagster-dbt", __version__)
