@@ -11,9 +11,12 @@ from ..errors import (
     DagsterDbtCliHandledRuntimeError,
     DagsterDbtCliOutputsNotFoundError,
 )
-from .constants import DBT_RUN_RESULTS_COMMANDS, DEFAULT_DBT_TARGET_PATH
 from .types import DbtCliOutput
 
+DEFAULT_DBT_TARGET_PATH = "target"
+
+DBT_RUN_RESULTS_COMMANDS = ["run", "test", "seed", "snapshot", "docs generate", "build"]
+
 
 class DbtCliEvent(NamedTuple):
     """Helper class to encapsulate parsed information from an active dbt CLI process."""
