@@ -8,13 +8,13 @@ from .types import DbtOutput
 
 
 class DbtResource:
-    """Base class for a resource allowing users to interface with dbt"""
+    """Base class for a resource allowing users to interface with dbt."""
 
     def __init__(
         self,
         logger: Optional[logging.Logger] = None,
     ):
-        """Constructor
+        """Constructor.
 
         Args:
             logger (Optional[Any]): A property for injecting a logger dependency.
@@ -25,11 +25,9 @@ class DbtResource:
     def _format_params(
         self, flags: Mapping[str, Any], replace_underscores: bool = False
     ) -> Mapping[str, Any]:
-        """
-        Reformats arguments that are easier to express as a list into the format that dbt expects,
+        """Reformats arguments that are easier to express as a list into the format that dbt expects,
         and deletes and keys with no value.
         """
-
         # remove any keys with a value of None
         if replace_underscores:
             flags = {k.replace("_", "-"): v for k, v in flags.items() if v is not None}
@@ -56,8 +54,7 @@ class DbtResource:
         exclude: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtOutput:
-        """
-        Run the ``compile`` command on a dbt project. kwargs are passed in as additional parameters.
+        """Run the ``compile`` command on a dbt project. kwargs are passed in as additional parameters.
 
         Args:
             models (List[str], optional): the models to include in compilation.
@@ -74,8 +71,7 @@ class DbtResource:
         exclude: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtOutput:
-        """
-        Run the ``run`` command on a dbt project. kwargs are passed in as additional parameters.
+        """Run the ``run`` command on a dbt project. kwargs are passed in as additional parameters.
 
         Args:
             models (List[str], optional): the models to include in the run.
@@ -92,8 +88,7 @@ class DbtResource:
         exclude: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtOutput:
-        """
-        Run the ``snapshot`` command on a dbt project. kwargs are passed in as additional parameters.
+        """Run the ``snapshot`` command on a dbt project. kwargs are passed in as additional parameters.
 
         Args:
             select (List[str], optional): the snapshots to include in the run.
@@ -112,8 +107,7 @@ class DbtResource:
         schema: bool = True,
         **kwargs,
     ) -> DbtOutput:
-        """
-        Run the ``test`` command on a dbt project. kwargs are passed in as additional parameters.
+        """Run the ``test`` command on a dbt project. kwargs are passed in as additional parameters.
 
         Args:
             models (List[str], optional): the models to include in testing.
@@ -133,8 +127,7 @@ class DbtResource:
         exclude: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtOutput:
-        """
-        Run the ``seed`` command on a dbt project. kwargs are passed in as additional parameters.
+        """Run the ``seed`` command on a dbt project. kwargs are passed in as additional parameters.
 
         Args:
             show (bool, optional): If ``True``, then show a sample of the seeded data in the
@@ -155,8 +148,7 @@ class DbtResource:
         exclude: Optional[Sequence[str]] = None,
         **kwargs,
     ) -> DbtOutput:
-        """
-        Run the ``ls`` command on a dbt project. kwargs are passed in as additional parameters.
+        """Run the ``ls`` command on a dbt project. kwargs are passed in as additional parameters.
 
         Args:
             select (List[str], optional): the resources to include in the output.
@@ -170,8 +162,7 @@ class DbtResource:
 
     @abstractmethod
     def build(self, select: Optional[Sequence[str]] = None, **kwargs) -> DbtOutput:
-        """
-        Run the ``build`` command on a dbt project. kwargs are passed in as additional parameters.
+        """Run the ``build`` command on a dbt project. kwargs are passed in as additional parameters.
 
         Args:
             select (List[str], optional): the models/resources to include in the run.
@@ -183,8 +174,7 @@ class DbtResource:
 
     @abstractmethod
     def generate_docs(self, compile_project: bool = False, **kwargs) -> DbtOutput:
-        """
-        Run the ``docs generate`` command on a dbt project. kwargs are passed in as additional parameters.
+        """Run the ``docs generate`` command on a dbt project. kwargs are passed in as additional parameters.
 
         Args:
             compile_project (bool, optional): If true, compile the project before generating a catalog.
@@ -197,8 +187,7 @@ class DbtResource:
     def run_operation(
         self, macro: str, args: Optional[Mapping[str, Any]] = None, **kwargs
     ) -> DbtOutput:
-        """
-        Run the ``run-operation`` command on a dbt project. kwargs are passed in as additional parameters.
+        """Run the ``run-operation`` command on a dbt project. kwargs are passed in as additional parameters.
 
         Args:
             macro (str): the dbt macro to invoke.
@@ -210,8 +199,7 @@ class DbtResource:
 
     @abstractmethod
     def get_run_results_json(self, **kwargs) -> Optional[Mapping[str, Any]]:
-        """
-        Get a parsed version of the run_results.json file for the relevant dbt project.
+        """Get a parsed version of the run_results.json file for the relevant dbt project.
 
         Returns:
             Dict[str, Any]: dictionary containing the parsed contents of the run_results json file
@@ -220,8 +208,7 @@ class DbtResource:
 
     @abstractmethod
     def get_manifest_json(self, **kwargs) -> Optional[Mapping[str, Any]]:
-        """
-        Get a parsed version of the manifest.json file for the relevant dbt project.
+        """Get a parsed version of the manifest.json file for the relevant dbt project.
 
         Returns:
             Dict[str, Any]: dictionary containing the parsed contents of the manifest json file
