@@ -4,8 +4,7 @@ import dagster._check as check
 
 
 class DbtOutput:
-    """
-    Base class for both DbtCliOutput and DbtRPCOutput. Contains a single field, `result`, which
+    """Base class for both DbtCliOutput and DbtRPCOutput. Contains a single field, `result`, which
     represents the dbt-formatted result of the command that was run (if any).
 
     Used internally, should not be instantiated directly by the user.
